Add conditional requiredness field, `instrument_required: str(required=False)`, that makes a key `required` if it comes from a header
from an instrument that matches the value passed to the spec field. E.g., if a key has `instrument_required: vbi` then any header
from the VBI instrument will make that key `required`.
